==> elgg-1.9.2.zip: elgg-1.9.2/mod/groups/languages/pl.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'groups' => "Grupy",
	'groups:owned' => "Własne grupy",
	'groups:owned:user' => 'Grupy użytkownika %s',
	'groups:yours' => "Twoje grupy",
	'groups:user' => "%s grupy",
	'groups:all' => "Wszystkie grupy",
	'groups:add' => "Utwórz nową grupę",
	'groups:edit' => "Edytuj grupę",
	'groups:delete' => 'Usuń grupę',
	'groups:membershiprequests' => 'Zarządzaj prośbami o dołączenie',
	'groups:membershiprequests:pending' => 'Zarządzaj prośbami o dołączenie (%s)',
	'groups:invitations' => 'Zaproszenia do grupy',
	'groups:invitations:pending' => 'Zaproszenia do grupy (%s)',

	'groups:icon' => 'Ikona grupy',
	'groups:name' => 'Nazwa grupy',
	'groups:username' => 'Krótka nazwa grupy (wyświetlana w adresach URL, tylko litery i cyfry)',
	'groups:description' => 'Opis',
	'groups:briefdescription' => 'Krótki opis',
	'groups:interests' => 'Zainteresowania',
	'groups:website' => 'Strona www',
	'groups:members' => 'Członkowie grupy',
	'groups:my_status' => 'Twój status',
	'groups:my_status:group_owner' => 'Jesteś właścicielem tej grupy',
	'groups:my_status:group_member' => 'Jesteś członkiem tej grupy',
	'groups:subscribed' => 'Powiadomienia grupy włączone',
	'groups:unsubscribed' => 'Powiadomienia grupy wyłączone',

	'groups:members:title' => 'Członkowie %s',
	'groups:members:more' => "Wyświetl wszystkich członków",
	'groups:membership' => "Członkostwo",
	'groups:content_access_mode' => "Poziom dostępu do treści grupy.",
	'groups:content_access_mode:warning' => "Uwaga: Zmiana tego ustawienia nie wpłynie na uprawnienia do treści istniejących już w grupie.",
	'groups:content_access_mode:unrestricted' => "Brak ograniczeń - Dostęp zależy od ustawień poszczególnych elementów",
	'groups:content_access_mode:membersonly' => "Tylko dla członków - Osoby spoza grupy nie mają dostępu do treści w grupie",
	'groups:access' => "Uprawnienia dostępu",
	'groups:owner' => "Właściciel",
	'groups:owner:warning' => "Uwaga: jeśli zmienisz tą wartość, to przestaniesz być właścicielem tej grupy.",
	'groups:widget:num_display' => 'Liczba grup do wyświetlenia',
	'groups:widget:membership' => 'Członkostwo grupy',
	'groups:widgets:description' => 'Wyświetl w profilu grupy do których należę',

	'groups:widget:group_activity:title' => 'Aktywność w grupie',
	'groups:widget:group_activity:description' => 'Wyświetla aktywność w jednej z twoich grup',
	'groups:widget:group_activity:edit:select' => 'Wybierz grupę',
	'groups:widget:group_activity:content:noactivity' => 'Brak aktywności w tej grupie',
	'groups:widget:group_activity:content:noselect' => 'Edytuj ustawienia gadżetu aby wybrać grupę',

	'groups:noaccess' => 'Brak dostępu do grupy',
	'groups:permissions:error' => 'Nie masz do tego uprawnień',
	'groups:ingroup' => 'w grupie',
	'groups:cantcreate' => 'Nie możesz utworzyć grupy. Tylko administrator ma taką możliwość.',
	'groups:cantedit' => 'Nie można edytować tej grupy',
	'groups:saved' => 'Grupa zapisana',
	'groups:featured' => 'Promowane grupy',
	'groups:makeunfeatured' => 'Przestań promować',
	'groups:makefeatured' => 'Promuj',
	'groups:featuredon' => '%s jest teraz promowaną grupą.',
	'groups:unfeatured' => '%s przestała być promowaną grupą.',
	'groups:featured_error' => 'Niepoprawna grupa.',
	'groups:joinrequest' => 'Prośba o członkostwo',
	'groups:join' => 'Dołącz do grupy',
	'groups:leave' => 'Odejdź z grupy',
	'groups:invite' => 'Zaproś przyjaciół',
	'groups:invite:title' => 'Zaproś znajomych do tej grupy',
	'groups:inviteto' => "Zaproszeni przyjaciele do '%s'",
	'groups:nofriends' => "Nie masz przyjaciół którzy zostali zaproszeni do tej grupy.",
	'groups:nofriendsatall' => 'Nie masz znajomych, których mógłbyś zaprosić!',
	'groups:viagroups' => "przez grupy",
	'groups:group' => "Grupa",
	'groups:search:tags' => "tag",
	'groups:search:title' => "Szukaj grup oznaczonych tagiem '%s'",
	'groups:search:none' => "Nie znaleziono pasujących grup",
	'groups:search_in_group' => "Szukaj w tej grupie",
	'groups:acl' => "Grupa: %s",

	'discussion:topic:notify:summary' => 'Nowy temat na forum o nazwie %s',
	'discussion:topic:notify:subject' => 'Nowy temat na forum: %s',
	'discussion:topic:notify:body' =>
'%s dodał nowy wątek w grupie %s:

Tytuł: %s

%s

Wyświetl i odpowiedz w wątku:
%s
',

	'discussion:reply:notify:summary' => 'Nowa odpowiedź w wątku: %s',
	'discussion:reply:notify:subject' => 'Nowa odpowiedź w wątku: %s',
	'discussion:reply:notify:body' =>
'%s dodał nową odpowiedź w wątku %s na forum w grupie %s:

%s

Wyświetl wpis i napisz odpowiedź:
%s',

	'groups:activity' => "Aktywność w grupie",
	'groups:enableactivity' => 'Włącz aktywność w grupie',
	'groups:activity:none' => "Jak na razie, brak aktywności w tej grupie",

	'groups:notfound' => "Nie znaleziono grupy",
	'groups:notfound:details' => "Wskazana grupa nie istnieje lub nie masz do niej dostępu",

	'groups:requests:none' => 'Nie ma obecnie próśb o dołączenie.',

	'groups:invitations:none' => 'Nie ma obecnie zaproszeń.',

	'item:object:groupforumtopic' => "Tematy forum",
	'item:object:discussion_reply' => "Odpowiedzi",

	'groupforumtopic:new' => "Dodaj wpis na forum",

	'groups:count' => "utworzonych grup",
	'groups:open' => "otwartych grup",
	'groups:closed' => "zamkniętych grup",
	'groups:member' => "członkowie",
	'groups:searchtag' => "Wyszukuj grupy za pomocą tagów",

	'groups:more' => 'Więcej grup',
	'groups:none' => 'Brak grup',

	/**
	 * Access
	 */
	'groups:access:private' => 'Zamknięta - Użytkownik musi mieć zaproszenie',
	'groups:access:public' => 'Otwarta - Każdy użytkownik może dołączyć',
	'groups:access:group' => 'Tylko członkowie grupy',
	'groups:closedgroup' => "Ta grupa jest zamknięta.",
	'groups:closedgroup:request' => 'Aby zostać dodanym, użyj linku "Prośba o członkostwo".',
	'groups:closedgroup:membersonly' => "Ta grupa jest zamknięta i jej treść jest dostępna wyłącznie dla członków.",
	'groups:opengroup:membersonly' => "Treść grupy jest dostępna tylko dla jej członków.",
	'groups:opengroup:membersonly:join' => 'Aby zostać członkiem, kliknij link "Dołącz do grupy".',
	'groups:visibility' => 'Kto może zobaczyć tą grupę?',

	/**
	 * Group tools
	 */
	'groups:enableforum' => 'Włącz forum grupy',
	'groups:lastupdated' => 'Ostatnia aktualizacja %s przez %s',
	'groups:lastcomment' => 'Ostatni komentarz %s przez %s',

	/**
	 * Group discussion
	 */
	'discussion' => 'Forum grupy',
	'discussion:add' => 'Dodaj wątek na forum',
	'discussion:latest' => 'Ostatnia dyskusja na forum',
	'discussion:group' => 'Forum grupy',
	'discussion:none' => 'Brak wpisów na forum',
	'discussion:reply:title' => 'Odpowiedź przez %s',

	'discussion:topic:created' => 'Wątek na forum utworzony pomyślnie.',
	'discussion:topic:updated' => 'Wątek na forum zaktualizowany pomyślnie.',
	'discussion:topic:deleted' => 'Wątek został pomyślnie usunięty z forum.',

	'discussion:topic:notfound' => 'Nie znaleziono wątku na forum',
	'discussion:error:notsaved' => 'Nie powiódł się zapis wątku na forum ',
	'discussion:error:missing' => 'Zarówno tytuł jak i treść są polami wymaganymi',
	'discussion:error:permissions' => 'Nie masz uprawnień do wykonania tej akcji',
	'discussion:error:notdeleted' => 'Nie można usunąć wątku z forum',

	'discussion:reply:edit' => 'Edytuj odpowiedź',
	'discussion:reply:deleted' => 'Pomyślnie usunięto odpowiedź z forum.',
	'discussion:reply:error:notfound' => 'Nie znaleziono wskazanej odpowiedzi na forum',
	'discussion:reply:error:notdeleted' => 'Usunięcie odpowiedzi z forum nie powiodło się',

	'admin:groups' => 'Grupy',

	'reply:this' => 'Napisz odpowiedź',

	'group:replies' => 'Odpowiedzi',
	'groups:forum:created' => 'Utworzono %s z %d komentarzami',
	'groups:forum:created:single' => 'Utworzono %s z %d odpowiedzią',
	'groups:forum' => 'Forum grupy',
	'groups:addtopic' => 'Dodaj temat',
	'groups:forumlatest' => 'Ostatnie forum',
	'groups:latestdiscussion' => 'Ostatnia dyskusja',
	'groupspost:success' => 'Twój komentarz został pomyślnie dodany',
	'groupspost:failure' => 'Wystąpił problem w trakcie zamieszczania twojej odpowiedzi',
	'groups:alldiscussion' => 'Ostatnie dyskusje',
	'groups:edittopic' => 'Edytuj temat',
	'groups:topicmessage' => 'Temat wiadomości',
	'groups:topicstatus' => 'Status tematu',
	'groups:reply' => 'Dodaj odpowiedź',
	'groups:topic' => 'Temat',
	'groups:posts' => 'Posty',
	'groups:lastperson' => 'Ostatnia osoba',
	'groups:when' => 'Kiedy',
	'grouptopic:notcreated' => 'Temat nie został utworzony.',
	'groups:topicclosed' => 'Zamknięty',
	'grouptopic:created' => 'Twój temat został utworzony.',
	'groups:topicsticky' => 'Przyklejony',
	'groups:topicisclosed' => 'Ten temat jest zamknięty.',
	'groups:topiccloseddesc' => 'Ten temat został już zamknięty.',
	'grouptopic:error' => 'Twój temat nie został utworzony. Spróbuj ponownie lub skontaktuj się z administratorem. ',
	'groups:forumpost:edited' => "Edycja wpisu na forum przebiegła pomyślnie.",
	'groups:forumpost:error' => "Nie powiodła się edycja wpisu na forum.",

	'groups:privategroup' => 'Ta grupa jest zamknięta, wysłaliśmy prośbę o członkostwo.',
	'groups:notitle' => 'Grupy muszą mieć tytuł',
	'groups:cantjoin' => 'Nie możesz dołączyć do grupy',
	'groups:cantleave' => 'Nie możesz odejść z grupy.',
	'groups:removeuser' => 'Usuń z grupy',
	'groups:cantremove' => 'Nie powiodło się usunięcie użytkownika z grupy',
	'groups:removed' => 'Pomyślnie usunięto %s z grupy',
	'groups:addedtogroup' => 'Użytkownik został pomyślnie dodany do tej grupy.',
	'groups:joinrequestnotmade' => 'Dołączenie do grupy nie powiodło się.',
	'groups:joinrequestmade' => 'Prośba o dołączenie do grupy wysłana pomyślnie',
	'groups:joined' => 'Pomyślnie dołączyłeś do grupy!',
	'groups:left' => 'Pomyślnie opuściłeś grupę',
	'groups:notowner' => 'Niestety, nie jesteś właścicielem tej grupy.',
	'groups:notmember' => 'Przykro nam, nie jesteś członkiem tej grupy.',
	'groups:alreadymember' => 'Jesteś już członkiem tej grupy!',
	'groups:userinvited' => 'Użytkownik został zaproszony.',
	'groups:usernotinvited' => 'Użytkownik nie został zaproszony.',
	'groups:useralreadyinvited' => 'Użytkownik już został zaproszony',
	'groups:invite:subject' => "%s zostałeś zaproszony do %s!",
	'groups:updated' => "Ostatnia odpowiedź przez %s %s",
	'groups:started' => "Rozpoczął %s",
	'groups:joinrequest:remove:check' => 'Czy na pewno chcesz usunąć tą prośbę o członkostwo?',
	'groups:invite:remove:check' => 'Czy na pewno chcesz usunąć to zaproszenie?',
	'groups:invite:body' => "Cześć %s,

Zostałeś zaproszony do '% s' grupy, kliknij przycisk poniżej aby potwierdzić:

%s",

	'groups:welcome:subject' => "Witamy w %s !",
	'groups:welcome:body' => "Cześć %s!
		
Jesteś już członkiem grupy \"% s\"! Kliknij poniżej aby rozpocząć postowanie!

%s",

	'groups:request:subject' => "%s wystąpił z prośbą o dołączenie do %s",
	'groups:request:body' => "Cześć %s,

%s wystąpił z wnioskiem o dołączenie do grupy '%s' , kliknij poniżej aby zobaczyć profil:

%s

lub kliknij poniżej aby potwierdzić prośbę:

%s",

	/**
	 * Forum river items
	 */

	'river:create:group:default' => '%s utworzył grupę %s',
	'river:join:group:default' => '%s dołączył do grupy %s',
	'river:create:object:groupforumtopic' => '%s dodał nowy wątek na forum grupy %s',
	'river:reply:object:groupforumtopic' => '%s napisał odpowiedź w wątku na forum grupy %s',

	'groups:nowidgets' => 'Żaden gadżet nie został zdefiniowany dla tej grupy.',


	'groups:widgets:members:title' => 'Użytkownicy grupy',
	'groups:widgets:members:description' => 'Lista użytkowników grupy.',
	'groups:widgets:members:label:displaynum' => 'Lista użytkowników grupy.',
	'groups:widgets:members:label:pleaseedit' => 'Proszę skonfigurować ten gadżet.',

	'groups:widgets:entities:title' => "Obiekty w grupie",
	'groups:widgets:entities:description' => "Lista obiektów zapisanych w grupie",
	'groups:widgets:entities:label:displaynum' => 'Lista obiektów w grupie.',
	'groups:widgets:entities:label:pleaseedit' => 'Proszę skonfigurować ten gadżet.',

	'groups:forumtopic:edited' => 'Temat forum został oprawiony.',

	'groups:allowhiddengroups' => 'Czy zezwolić na prywatne (niewidoczne) grupy?',
	'groups:whocancreate' => 'Kto może utworzyć nową grupę?',

	/**
	 * Action messages
	 */
	'group:deleted' => 'Grupa i zawartość grupy zostały usunięte',
	'group:notdeleted' => 'Nie powiodło się usunięcie grupy',

	'group:notfound' => 'Nie można znaleźć grupy',
	'grouppost:deleted' => 'Pomyślnie usunięto wpis z forum grupy',
	'grouppost:notdeleted' => 'Nie powiodło się usunięcie wpisu z forum grupy',
	'groupstopic:deleted' => 'Temat skasowany',
	'groupstopic:notdeleted' => 'Nie powiodło się usunięcie wątku',
	'grouptopic:blank' => 'Brak wątku',
	'grouptopic:notfound' => 'Nie można znaleźć wątku',
	'grouppost:nopost' => 'Pusty wpis',
	'groups:deletewarning' => "Czy na pewno chcesz usunąć tą grupę? Tej operacji nie można cofnąć!",

	'groups:invitekilled' => 'Usunięto zaproszenie.',
	'groups:joinrequestkilled' => 'Usunięto prośbę o członkostwo.',

	/**
	 * ecml
	 */
	'groups:ecml:discussion' => 'Forum grupy',
	'groups:ecml:groupprofile' => 'Profile grupy',
);

==> elgg-1.11.0.zip: elgg-1.11.0/mod/groups/languages/pl.php <==
<?php
return array(

	/**
	 * Menu items and titles
	 */
	'groups' => "Grupy",
	'groups:owned' => "Własne grupy",
	'groups:owned:user' => 'Grupy użytkownika %s',
	'groups:yours' => "Twoje grupy",
	'groups:user' => "%s grupy",
	'groups:all' => "Wszystkie grupy",
	'groups:add' => "Utwórz nową grupę",
	'groups:edit' => "Edytuj grupę",
	'groups:delete' => 'Usuń grupę',
	'groups:membershiprequests' => 'Zarządzaj prośbami o dołączenie',
	'groups:membershiprequests:pending' => 'Zarządzaj prośbami o dołączenie (%s)',
	'groups:invitations' => 'Zaproszenia do grupy',
	'groups:invitations:pending' => 'Zaproszenia do grupy (%s)',

	'groups:icon' => 'Ikona grupy',
	'groups:name' => 'Nazwa grupy',
	'groups:username' => 'Krótka nazwa grupy (wyświetlana w adresach URL, tylko litery i cyfry)',
	'groups:description' => 'Opis',
	'groups:briefdescription' => 'Krótki opis',
	'groups:interests' => 'Zainteresowania',
	'groups:website' => 'Strona www',
	'groups:members' => 'Członkowie grupy',
	'groups:my_status' => 'Twój status',
	'groups:my_status:group_owner' => 'Jesteś właścicielem tej grupy',
	'groups:my_status:group_member' => 'Jesteś członkiem tej grupy',
	'groups:subscribed' => 'Powiadomienia grupy włączone',
	'groups:unsubscribed' => 'Powiadomienia grupy wyłączone',

	'groups:members:title' => 'Członkowie %s',
	'groups:members:more' => "Wyświetl wszystkich członków",
	'groups:membership' => "Członkostwo",
	'groups:content_access_mode' => "Poziom dostępu do treści grupy.",
	'groups:content_access_mode:warning' => "Uwaga: Zmiana tego ustawienia nie wpłynie na uprawnienia do treści istniejących już w grupie.",
	'groups:content_access_mode:unrestricted' => "Brak ograniczeń - Dostęp zależy od ustawień poszczególnych elementów",
	'groups:content_access_mode:membersonly' => "Tylko dla członków - Osoby spoza grupy nie mają dostępu do treści w grupie",
	'groups:access' => "Uprawnienia dostępu",
	'groups:owner' => "Właściciel",
	'groups:owner:warning' => "Uwaga: jeśli zmienisz tą wartość, to przestaniesz być właścicielem tej grupy.",
	'groups:widget:num_display' => 'Liczba grup do wyświetlenia',
	'groups:widget:membership' => 'Członkostwo grupy',
	'groups:widgets:description' => 'Wyświetl w profilu grupy do których należę',

	'groups:widget:group_activity:title' => 'Aktywność w grupie',
	'groups:widget:group_activity:description' => 'Wyświetla aktywność w jednej z twoich grup',
	'groups:widget:group_activity:edit:select' => 'Wybierz grupę',
	'groups:widget:group_activity:content:noactivity' => 'Brak aktywności w tej grupie',
	'groups:widget:group_activity:content:noselect' => 'Edytuj ustawienia gadżetu aby wybrać grupę',

	'groups:noaccess' => 'Brak dostępu do grupy',
	'groups:permissions:error' => 'Nie masz do tego uprawnień',
	'groups:ingroup' => 'w grupie',
	'groups:cantcreate' => 'Nie możesz utworzyć grupy. Tylko administrator ma taką możliwość.',
	'groups:cantedit' => 'Nie można edytować tej grupy',
	'groups:saved' => 'Grupa zapisana',
	'groups:featured' => 'Promowane grupy',
	'groups:makeunfeatured' => 'Przestań promować',
	'groups:makefeatured' => 'Promuj',
	'groups:featuredon' => '%s jest teraz promowaną grupą.',
	'groups:unfeatured' => '%s przestała być promowaną grupą.',
	'groups:featured_error' => 'Niepoprawna grupa.',
	'groups:nofeatured' => 'Brak wyróżnionych grup',
	'groups:joinrequest' => 'Prośba o członkostwo',
	'groups:join' => 'Dołącz do grupy',
	'groups:leave' => 'Odejdź z grupy',
	'groups:invite' => 'Zaproś przyjaciół',
	'groups:invite:title' => 'Zaproś znajomych do tej grupy',
	'groups:inviteto' => "Zaproszeni przyjaciele do '%s'",
	'groups:nofriends' => "Nie masz przyjaciół którzy zostali zaproszeni do tej grupy.",
	'groups:nofriendsatall' => 'Nie masz znajomych, których mógłbyś zaprosić!',
	'groups:viagroups' => "przez grupy",
	'groups:group' => "Grupa",
	'groups:search:tags' => "tag",
	'groups:search:title' => "Szukaj grup oznaczonych tagiem '%s'",
	'groups:search:none' => "Nie znaleziono pasujących grup",
	'groups:search_in_group' => "Szukaj w tej grupie",
	'groups:acl' => "Grupa: %s",

	'discussion:topic:notify:summary' => 'Nowy temat na forum o nazwie %s',
	'discussion:topic:notify:subject' => 'Nowy temat na forum: %s',
	'discussion:topic:notify:body' =>
'%s dodał nowy wątek w grupie %s:

Tytuł: %s

%s

Wyświetl i odpowiedz w wątku:
%s
',

	'discussion:reply:notify:summary' => 'Nowa odpowiedź w wątku: %s',
	'discussion:reply:notify:subject' => 'Nowa odpowiedź w wątku: %s',
	'discussion:reply:notify:body' =>
'%s dodał nową odpowiedź w wątku %s na forum w grupie %s:

%s

Wyświetl wpis i napisz odpowiedź:
%s',

	'groups:activity' => "Aktywność w grupie",
	'groups:enableactivity' => 'Włącz aktywność w grupie',
	'groups:activity:none' => "Jak na razie, brak aktywności w tej grupie",

	'groups:notfound' => "Nie znaleziono grupy",
	'groups:notfound:details' => "Wskazana grupa nie istnieje lub nie masz do niej dostępu",

	'groups:requests:none' => 'Nie ma obecnie próśb o dołączenie.',

	'groups:invitations:none' => 'Nie ma obecnie zaproszeń.',

	'item:object:groupforumtopic' => "Tematy forum",
	'item:object:discussion_reply' => "Odpowiedzi",

	'groupforumtopic:new' => "Dodaj wpis na forum",

	'groups:count' => "utworzonych grup",
	'groups:open' => "otwartych grup",
	'groups:closed' => "zamkniętych grup",
	'groups:member' => "członkowie",
	'groups:searchtag' => "Wyszukuj grupy za pomocą tagów",

	'groups:more' => 'Więcej grup',
	'groups:none' => 'Brak grup',

	/**
	 * Access
	 */
	'groups:access:private' => 'Zamknięta - Użytkownik musi mieć zaproszenie',
	'groups:access:public' => 'Otwarta - Każdy użytkownik może dołączyć',
	'groups:access:group' => 'Tylko członkowie grupy',
	'groups:closedgroup' => "Ta grupa jest zamknięta.",
	'groups:closedgroup:request' => 'Aby zostać dodanym, użyj linku "Prośba o członkostwo".',
	'groups:closedgroup:membersonly' => "Ta grupa jest zamknięta i jej treść jest dostępna wyłącznie dla członków.",
	'groups:opengroup:membersonly' => "Treść grupy jest dostępna tylko dla jej członków.",
	'groups:opengroup:membersonly:join' => 'Aby zostać członkiem, kliknij link "Dołącz do grupy".',
	'groups:visibility' => 'Kto może zobaczyć tą grupę?',

	/**
	 * Group tools
	 */
	'groups:enableforum' => 'Włącz forum grupy',
	'groups:lastupdated' => 'Ostatnia aktualizacja %s przez %s',
	'groups:lastcomment' => 'Ostatni komentarz %s przez %s',

	/**
	 * Group discussion
	 */
	'discussion' => 'Forum grupy',
	'discussion:add' => 'Dodaj wątek na forum',
	'discussion:latest' => 'Ostatnia dyskusja na forum',
	'discussion:group' => 'Forum grupy',
	'discussion:none' => 'Brak wpisów na forum',
	'discussion:reply:title' => 'Odpowiedź przez %s',

	'discussion:topic:created' => 'Wątek na forum utworzony pomyślnie.',
	'discussion:topic:updated' => 'Wątek na forum zaktualizowany pomyślnie.',
	'discussion:topic:deleted' => 'Wątek został pomyślnie usunięty z forum.',

	'discussion:topic:notfound' => 'Nie znaleziono wątku na forum',
	'discussion:error:notsaved' => 'Nie powiódł się zapis wątku na forum ',
	'discussion:error:missing' => 'Zarówno tytuł jak i treść są polami wymaganymi',
	'discussion:error:permissions' => 'Nie masz uprawnień do wykonania tej akcji',
	'discussion:error:notdeleted' => 'Nie można usunąć wątku z forum',

	'discussion:reply:edit' => 'Edytuj odpowiedź',
	'discussion:reply:deleted' => 'Pomyślnie usunięto odpowiedź z forum.',
	'discussion:reply:error:notfound' => 'Nie znaleziono wskazanej odpowiedzi na forum',
	'discussion:reply:error:notfound_fallback' => "Przykro nam, nie znaleźliśmy wskazanej odpowiedzi, pomimo, że przesłaliśmy oryginalny wątek dyskusji.",
	'discussion:reply:error:notdeleted' => 'Usunięcie odpowiedzi z forum nie powiodło się',

	'discussion:search:title' => 'Odpowiedź na temat: %s',
	
	'admin:groups' => 'Grupy',

	'reply:this' => 'Napisz odpowiedź',

	'group:replies' => 'Odpowiedzi',
	'groups:forum:created' => 'Utworzono %s z %d komentarzami',
	'groups:forum:created:single' => 'Utworzono %s z %d odpowiedzią',
	'groups:forum' => 'Forum grupy',
	'groups:addtopic' => 'Dodaj temat',
	'groups:forumlatest' => 'Ostatnie forum',
	'groups:latestdiscussion' => 'Ostatnia dyskusja',
	'groupspost:success' => 'Twój komentarz został pomyślnie dodany',
	'groupspost:failure' => 'Wystąpił problem w trakcie zamieszczania twojej odpowiedzi',
	'groups:alldiscussion' => 'Ostatnie dyskusje',
	'groups:edittopic' => 'Edytuj temat',
	'groups:topicmessage' => 'Temat wiadomości',
	'groups:topicstatus' => 'Status tematu',
	'groups:reply' => 'Dodaj odpowiedź',
	'groups:topic' => 'Temat',
	'groups:posts' => 'Posty',
	'groups:lastperson' => 'Ostatnia osoba',
	'groups:when' => 'Kiedy',
	'grouptopic:notcreated' => 'Temat nie został utworzony.',
	'groups:topicclosed' => 'Zamknięty',
	'grouptopic:created' => 'Twój temat został utworzony.',
	'groups:topicsticky' => 'Przyklejony',
	'groups:topicisclosed' => 'Ten temat jest zamknięty.',
	'groups:topiccloseddesc' => 'Ten temat został już zamknięty.',
	'grouptopic:error' => 'Twój temat nie został utworzony. Spróbuj ponownie lub skontaktuj się z administratorem. ',
	'groups:forumpost:edited' => "Edycja wpisu na forum przebiegła pomyślnie.",
	'groups:forumpost:error' => "Nie powiodła się edycja wpisu na forum.",

	'groups:privategroup' => 'Ta grupa jest zamknięta, wysłaliśmy prośbę o członkostwo.',
	'groups:notitle' => 'Grupy muszą mieć tytuł',
	'groups:cantjoin' => 'Nie możesz dołączyć do grupy',
	'groups:cantleave' => 'Nie możesz odejść z grupy.',
	'groups:removeuser' => 'Usuń z grupy',
	'groups:cantremove' => 'Nie powiodło się usunięcie użytkownika z grupy',
	'groups:removed' => 'Pomyślnie usunięto %s z grupy',
	'groups:addedtogroup' => 'Użytkownik został pomyślnie dodany do tej grupy.',
	'groups:joinrequestnotmade' => 'Dołączenie do grupy nie powiodło się.',
	'groups:joinrequestmade' => 'Prośba o dołączenie do grupy wysłana pomyślnie',
	'groups:joined' => 'Pomyślnie dołączyłeś do grupy!',
	'groups:left' => 'Pomyślnie opuściłeś grupę',
	'groups:notowner' => 'Niestety, nie jesteś właścicielem tej grupy.',
	'groups:notmember' => 'Przykro nam, nie jesteś członkiem tej grupy.',
	'groups:alreadymember' => 'Jesteś już członkiem tej grupy!',
	'groups:userinvited' => 'Użytkownik został zaproszony.',
	'groups:usernotinvited' => 'Użytkownik nie został zaproszony.',
	'groups:useralreadyinvited' => 'Użytkownik już został zaproszony',
	'groups:invite:subject' => "%s zostałeś zaproszony do %s!",
	'groups:updated' => "Ostatnia odpowiedź przez %s %s",
	'groups:started' => "Rozpoczął %s",
	'groups:joinrequest:remove:check' => 'Czy na pewno chcesz usunąć tą prośbę o członkostwo?',
	'groups:invite:remove:check' => 'Czy na pewno chcesz usunąć to zaproszenie?',
	'groups:invite:body' => "Cześć %s,

Zostałeś zaproszony do '% s' grupy, kliknij przycisk poniżej aby potwierdzić:

%s",

	'groups:welcome:subject' => "Witamy w %s !",
	'groups:welcome:body' => "Cześć %s!
		
Jesteś już członkiem grupy \"% s\"! Kliknij poniżej aby rozpocząć postowanie!

%s",

	'groups:request:subject' => "%s wystąpił z prośbą o dołączenie do %s",
	'groups:request:body' => "Cześć %s,

%s wystąpił z wnioskiem o dołączenie do grupy '%s' , kliknij poniżej aby zobaczyć profil:

%s

lub kliknij poniżej aby potwierdzić prośbę:

%s",

	/**
	 * Forum river items
	 */

	'river:create:group:default' => '%s utworzył grupę %s',
	'river:join:group:default' => '%s dołączył do grupy %s',
	'river:create:object:groupforumtopic' => '%s dodał nowy wątek na forum grupy %s',
	'river:reply:object:groupforumtopic' => '%s napisał odpowiedź w wątku na forum grupy %s',
	'river:reply:view' => 'zobacz odpowiedź',

	'groups:nowidgets' => 'Żaden gadżet nie został zdefiniowany dla tej grupy.',


	'groups:widgets:members:title' => 'Użytkownicy grupy',
	'groups:widgets:members:description' => 'Lista użytkowników grupy.',
	'groups:widgets:members:label:displaynum' => 'Lista użytkowników grupy.',
	'groups:widgets:members:label:pleaseedit' => 'Proszę skonfigurować ten gadżet.',

	'groups:widgets:entities:title' => "Obiekty w grupie",
	'groups:widgets:entities:description' => "Lista obiektów zapisanych w grupie",
	'groups:widgets:entities:label:displaynum' => 'Lista obiektów w grupie.',
	'groups:widgets:entities:label:pleaseedit' => 'Proszę skonfigurować ten gadżet.',

	'groups:forumtopic:edited' => 'Temat forum został oprawiony.',

	'groups:allowhiddengroups' => 'Czy zezwolić na prywatne (niewidoczne) grupy?',
	'groups:whocancreate' => 'Kto może utworzyć nową grupę?',

	/**
	 * Action messages
	 */
	'group:deleted' => 'Grupa i zawartość grupy zostały usunięte',
	'group:notdeleted' => 'Nie powiodło się usunięcie grupy',

	'group:notfound' => 'Nie można znaleźć grupy',
	'grouppost:deleted' => 'Pomyślnie usunięto wpis z forum grupy',
	'grouppost:notdeleted' => 'Nie powiodło się usunięcie wpisu z forum grupy',
	'groupstopic:deleted' => 'Temat skasowany',
	'groupstopic:notdeleted' => 'Nie powiodło się usunięcie wątku',
	'grouptopic:blank' => 'Brak wątku',
	'grouptopic:notfound' => 'Nie można znaleźć wątku',
	'grouppost:nopost' => 'Pusty wpis',
	'groups:deletewarning' => "Czy na pewno chcesz usunąć tą grupę? Tej operacji nie można cofnąć!",

	'groups:invitekilled' => 'Usunięto zaproszenie.',
	'groups:joinrequestkilled' => 'Usunięto prośbę o członkostwo.',
	'groups:error:addedtogroup' => "Nie można było dodać %s do grupy",
	'groups:add:alreadymember' => "%s jest już członkiem tej grupy",

	/**
	 * ecml
	 */
	'groups:ecml:discussion' => 'Forum grupy',
	'groups:ecml:groupprofile' => 'Profile grupy',
);
